@@ -37,8 +37,11 @@ exception statement from your version.  */
 
 package gnu.java.net.protocol.file;
 
+import gnu.classpath.SystemProperties;
+
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
+import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
@@ -50,10 +53,9 @@ import java.net.ProtocolException;
 import java.net.URL;
 import java.net.URLConnection;
 import java.security.Permission;
-import java.util.AbstractSet;
-import java.util.Iterator;
-import java.util.Set;
-import java.util.NoSuchElementException;
+import java.text.SimpleDateFormat;
+import java.util.Date;
+import java.util.Locale;
 
 /**
  * This subclass of java.net.URLConnection models a URLConnection via
@@ -70,6 +72,20 @@ public class Connection extends URLConnection
    */
   private static final String DEFAULT_PERMISSION = "read";
 
+  private static class StaticData
+  {
+    /**
+     * HTTP-style DateFormat, used to format the last-modified header.
+     */
+    static SimpleDateFormat dateFormat
+      = new SimpleDateFormat("EEE, dd MMM yyyy hh:mm:ss 'GMT'",
+                             new Locale ("En", "Us", "Unix"));
+
+    static String lineSeparator =
+      SystemProperties.getProperty("line.separator");
+  }
+
+  
   /**
    * This is a File object for this connection
    */
@@ -111,11 +127,32 @@ public class Connection extends URLConnection
     
     // If not connected, then file needs to be openned.
     file = new File (getURL().getFile());
-    if (doInput)
-      inputStream = new BufferedInputStream(new FileInputStream(file));
+
+    if (! file.isDirectory())
+      {
+	if (doInput)
+	  inputStream = new BufferedInputStream(new FileInputStream(file));
     
-    if (doOutput)
-      outputStream = new BufferedOutputStream(new FileOutputStream(file));
+	if (doOutput)
+	  outputStream = new BufferedOutputStream(new FileOutputStream(file));
+      }
+    else
+      {
+	if (doInput)
+	  {
+	    StringBuffer sb = new StringBuffer();
+	    String[] files = file.list();
+
+	    for (int index = 0; index < files.length; ++index)
+	       sb.append(files[index]).append(StaticData.lineSeparator);
+
+	    inputStream = new ByteArrayInputStream(sb.toString().getBytes());
+	  }
+
+	if (doOutput)
+	  throw new ProtocolException
+	    ("file: protocol does not support output on directories");
+      }
     
     connected = true;
   }
@@ -178,6 +215,36 @@ public class Connection extends URLConnection
 	return -1;
       }
   }
+  
+  /**
+   *  Get an http-style header field. Just handle a few common ones. 
+   */
+  public String getHeaderField(String field)
+  {
+    try
+      {
+	if (!connected)
+	  connect();
+
+	if (field.equals("content-type"))
+          return guessContentTypeFromName(file.getName());
+	else if (field.equals("content-length"))
+          return Long.toString(file.length());
+	else if (field.equals("last-modified"))
+	  {
+	    synchronized (StaticData.dateFormat)
+	      {
+        	return StaticData.dateFormat.format(
+                        new Date(file.lastModified()));
+	      }
+	  }
+      }
+    catch (IOException e)
+      {
+        // Fall through.
+      }
+    return null;
+  }
 
   /**
    * Get the length of content.
@@ -211,105 +278,4 @@ public class Connection extends URLConnection
   {
     return permission;
   }
-
-  /**
-   * Does the resource pointed to actually exist?
-   */
-  public final boolean exists()
-  {
-    if (file == null)
-      return false;
-
-    return file.exists();
-  }
-
-  /**
-   * Is the resource pointed to a directory?
-   */
-  public final boolean isDirectory()
-  {
-    return file.isDirectory();
-  }
-  
-  /**
-   * Get a listing of the directory, if it is a directory.
-   *
-   * @return a set which can supply an iteration of the
-   * contents of the directory.
-   *
-   * @throws IllegalStateException if this is not pointing
-   * to a directory.
-   */
-  public Set getListing()
-  {
-    if (!file.isDirectory())
-      throw new IllegalStateException ("this is not a directory");
-    
-    final File[] directoryList = file.listFiles();
-    return new AbstractSet()
-      {
-	File[] dirList = directoryList;
-
-	public int size()
-	{
-	  return dirList.length;
-	}
-
-	public Iterator iterator()
-	{
-	  return new Iterator()
-	    {
-	      int index = 0;
-
-	      public boolean hasNext()
-	      {
-		return index < dirList.length;
-	      }
-
-	      public Object next()
-	      {
-		try
-		  {
-		    String value = dirList [index++].getName();
-		    return value;
-		  }
-		catch (ArrayIndexOutOfBoundsException e)
-		  {
-		    throw new NoSuchElementException ("no more content");
-		  }
-	      }
-
-	      public void remove()
-	      {
-		try
-		  {
-		    File[] newDirList = new File [dirList.length - 1];
-		    int realIndex = index - 1;
-                    
-		    if (realIndex < 1)
-		      {
-			System.arraycopy (dirList, 1, newDirList, 0,
-                                          dirList.length - 1);
-			index--;
-		      }
-		    else
-		      {
-			System.arraycopy (dirList, 0, newDirList, 0, realIndex);
-                        
-			if (index < dirList.length - 1)
-			  System.arraycopy (dirList, index,
-					    newDirList, realIndex,
-                                            dirList.length - realIndex);
-		      }
-		    dirList = newDirList;
-		  }
-		catch (ArrayIndexOutOfBoundsException e)
-		  {
-		    throw new NoSuchElementException("no more content");
-		  }
-	      }
-	    };
-	}
-      };
-  }
 }
