@@ -54,12 +54,10 @@ import java.net.InetSocketAddress;
 import java.net.Socket;
 import java.security.GeneralSecurityException;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import javax.net.SocketFactory;
 import javax.net.ssl.HandshakeCompletedListener;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLSocket;
@@ -366,10 +364,18 @@ public class HTTPConnection
       }
     if (path == null || path.length() == 0)
       {
-        throw new IllegalArgumentException("path must have non-zero length");
+        path = "/";
       }
     Request ret = new Request(this, method, path);
-    ret.setHeader("Host", hostname);
+    if ((secure && port != HTTPS_PORT) ||
+        (!secure && port != HTTP_PORT))
+      {
+        ret.setHeader("Host", hostname + ":" + port);
+      }
+    else
+      {
+        ret.setHeader("Host", hostname);
+      }
     ret.setHeader("User-Agent", userAgent);
     ret.setHeader("Connection", "keep-alive");
     ret.setHeader("Accept-Encoding",
