@@ -1,5 +1,5 @@
 /* Class.java -- Representation of a Java class.
-   Copyright (C) 1998, 1999, 2000, 2002, 2003, 2004
+   Copyright (C) 1998, 1999, 2000, 2002, 2003, 2004, 2005
    Free Software Foundation
 
 This file is part of GNU Classpath.
@@ -38,6 +38,8 @@ exception statement from your version. */
 
 package java.lang;
 
+import gnu.classpath.VMStackWalker;
+
 import java.io.InputStream;
 import java.io.Serializable;
 import java.lang.reflect.Constructor;
@@ -157,7 +159,7 @@ public final class Class implements Serializable
     Class result = VMClass.forName (name);
     if (result == null)
       result = Class.forName(name, true,
-			     VMSecurityManager.getClassContext()[1].getClassLoader());
+	VMStackWalker.getCallingClassLoader());
     return result;
   }
 
@@ -198,9 +200,8 @@ public final class Class implements Serializable
         SecurityManager sm = SecurityManager.current;
         if (sm != null)
           {
-            // Get the calling class and classloader
-            Class c = VMSecurityManager.getClassContext()[1];
-            ClassLoader cl = c.getClassLoader();
+            // Get the calling classloader
+            ClassLoader cl = VMStackWalker.getCallingClassLoader();
             if (cl != null)
               sm.checkPermission(new RuntimePermission("getClassLoader"));
           }
@@ -278,9 +279,8 @@ public final class Class implements Serializable
     SecurityManager sm = SecurityManager.current;
     if (sm != null)
       {
-        // Get the calling class and classloader
-        Class c = VMSecurityManager.getClassContext()[1];
-        ClassLoader cl = VMClass.getClassLoader(c);
+        // Get the calling classloader
+	ClassLoader cl = VMStackWalker.getCallingClassLoader();
         if (cl != null && !cl.isAncestorOf(loader))
           sm.checkPermission(new RuntimePermission("getClassLoader"));
       }
@@ -1116,8 +1116,10 @@ public final class Class implements Serializable
 	if (!Modifier.isPublic(constructor.getModifiers()))
 	  {
 	    final Constructor finalConstructor = constructor;
-	    AccessController.doPrivileged(new PrivilegedAction() {
-		public Object run() {
+	    AccessController.doPrivileged(new PrivilegedAction()
+	      {
+		public Object run()
+	        {
 		  finalConstructor.setAccessible(true);
 		  return null;
 		}
@@ -1132,8 +1134,9 @@ public final class Class implements Serializable
     int modifiers = constructor.getModifiers();
     if (!Modifier.isPublic(modifiers))
       {
-	Class caller = VMSecurityManager.getClassContext()[1];
-	if (caller != this &&
+	Class caller = VMStackWalker.getCallingClass();
+	if (caller != null &&
+	    caller != this &&
 	    (Modifier.isPrivate(modifiers)
 	     || getClassLoader() != caller.getClassLoader()
 	     || !getPackagePortion(getName())
