@@ -174,7 +174,7 @@ public class AlgorithmParameterGenerator
 
     Provider p = Security.getProvider(provider);
     if (p == null)
-      throw new NoSuchProviderException();
+      throw new NoSuchProviderException(provider);
 
     return getInstance(algorithm, p);
   }
