@@ -1,5 +1,5 @@
 /* ResourceBundle -- aids in loading resource bundles
-   Copyright (C) 1998, 1999, 2001, 2002, 2003, 2004
+   Copyright (C) 1998, 1999, 2001, 2002, 2003, 2004, 2005
    Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
@@ -39,10 +39,10 @@ exception statement from your version. */
 
 package java.util;
 
+import gnu.classpath.VMStackWalker;
+
 import java.io.IOException;
 import java.io.InputStream;
-import java.security.AccessController;
-import java.security.PrivilegedAction;
 
 /**
  * A resource bundle contains locale-specific data. If you need localized
@@ -103,48 +103,6 @@ public abstract class ResourceBundle
    */
   private Locale locale;
 
-  /**
-   * We override SecurityManager in order to access getClassContext().
-   */
-  private static final class Security extends SecurityManager
-  {
-    /**
-     * Avoid accessor method of private constructor.
-     */
-    Security()
-    {
-    }
-
-    /**
-     * Return the ClassLoader of the class which called into this
-     * ResourceBundle, or null if it cannot be determined.
-     */
-    ClassLoader getCallingClassLoader()
-    {
-      Class[] stack = getClassContext();
-      for (int i = 0; i < stack.length; i++)
-       {
-	 if (stack[i] != Security.class && stack[i] != ResourceBundle.class)
-	   return stack[i].getClassLoader();
-       }
-
-      return null;
-    }
-  }
-
-  /** A security context for grabbing the correct class loader. */
-  private static final Security security
-    = (Security) AccessController.doPrivileged(new PrivilegedAction()
-      {
-	// This will always work since java.util classes have (all) system
-	// permissions.
-	public Object run()
-	{
-	  return new Security();
-	}
-      }
-    );
-
   /**
    * The resource bundle cache.
    */
@@ -215,9 +173,11 @@ public abstract class ResourceBundle
         if (o != null)
           return o;
       }
- 
-    throw new MissingResourceException("Key not found", getClass().getName(),
-				       key);
+
+    String className = getClass().getName();
+    throw new MissingResourceException("Key '" + key
+				       + "'not found in Bundle: "
+				       + className, className, key);
   }
 
   /**
@@ -256,7 +216,7 @@ public abstract class ResourceBundle
    */
   public static ResourceBundle getBundle(String baseName)
   {
-    ClassLoader cl = security.getCallingClassLoader();
+    ClassLoader cl = VMStackWalker.getCallingClassLoader();
     if (cl == null)
       cl = ClassLoader.getSystemClassLoader();
     return getBundle(baseName, Locale.getDefault(), cl);
@@ -276,7 +236,7 @@ public abstract class ResourceBundle
    */
   public static ResourceBundle getBundle(String baseName, Locale locale)
   {
-    ClassLoader cl = security.getCallingClassLoader();
+    ClassLoader cl = VMStackWalker.getCallingClassLoader();
     if (cl == null)
       cl = ClassLoader.getSystemClassLoader();
     return getBundle(baseName, locale, cl);
@@ -533,7 +493,7 @@ public abstract class ResourceBundle
 	catch (IOException ex)
 	  {
 	    MissingResourceException mre = new MissingResourceException
-	      ("Failed to load bundle", localizedName, "");
+	      ("Failed to load bundle: " + localizedName, localizedName, "");
 	    mre.initCause(ex);
 	    throw mre;
 	  }
