@@ -72,6 +72,14 @@ public class Timer implements Serializable
   /** DOCUMENT ME! */
   private Waker waker;
 
+  private Runnable drainer = new Runnable() 
+    {
+      public void run()
+      {
+        drainEvents();
+      }
+    };
+
   /**
    * DOCUMENT ME!
    */
@@ -81,14 +89,7 @@ public class Timer implements Serializable
       {
 	queue++;
 	if (queue == 1)
-	  SwingUtilities.invokeLater(new Runnable()
-	      {
-		public void run()
-		{
-		  drainEvents();
-		}
-	      });
-
+	  SwingUtilities.invokeLater(drainer);
       }
   }
 
@@ -150,6 +151,8 @@ public class Timer implements Serializable
       try
         {
 	  sleep(initialDelay);
+	  
+	  queueEvent();
 
 	  while (running)
 	    {
@@ -181,12 +184,14 @@ public class Timer implements Serializable
   /**
    * Creates a new Timer object.
    *
-   * @param d DOCUMENT ME!
-   * @param listener DOCUMENT ME!
+   * @param d the default value for both initial and between event delay, in
+   * milliseconds.
+   * @param listener the first action listener, can be <code>null</code>.
    */
   public Timer(int d, ActionListener listener)
   {
     delay = d;
+	initialDelay = d;
 
     if (listener != null)
       addActionListener(listener);
