@@ -1,24 +1,23 @@
 #!/bin/sh
 
-TMPFILE=`mktemp`
-TMPFILE2=`mktemp`
-TMPFILE3=`mktemp`
+TMPFILE=check-jni-methods.$$.1
+TMPFILE2=check-jni-methods.$$.2
+TMPFILE3=check-jni-methods.$$.3
 
 # Find all methods defined in the header files generated
 # from the java source files.
 grep -h '^JNIEXPORT .* Java_' include/*.h | \
-	sed -e 's,^JNIEXPORT .* JNICALL \(Java_\w*\) (.*$,\1,' | \
+        LC_ALL=C sed -e 's,.*JNICALL \(Java_[a-z_A-Z0-9]*\).*$,\1,' | \
 	sort > $TMPFILE
 
 # Find all methods in the JNI C source files.
 find native/jni -name \*.c | \
 	xargs grep -h '^Java_' | \
-	sed -e 's,^\(Java_\w*\) *(.*$,\1,' \
-	| sort > $TMPFILE2
+        LC_ALL=C sed -e 's,^\(Java_[a-z_A-Z0-9]*\) *(.*$,\1,' | \
+	sort > $TMPFILE2
 
 # Write temporary ignore file.
 cat > $TMPFILE3 << EOF
--Java_gnu_java_awt_peer_gtk_GtkFramePeer_nativeSetIconImageFromData
 -Java_gnu_java_awt_peer_gtk_GtkMenuComponentPeer_dispose
 -Java_java_lang_VMSystem_arraycopy
 -Java_java_lang_VMSystem_identityHashCode
